@@ -323,6 +323,8 @@ typedef struct {
    BOOLEAN          EnableMouse;
    BOOLEAN          EnableTouch;
    BOOLEAN          HiddenTags;
+   BOOLEAN          UseNvram;
+   BOOLEAN          ShutdownAfterTimeout;
    UINTN            RequestedScreenWidth;
    UINTN            RequestedScreenHeight;
    UINTN            BannerBottomEdge;
