@@ -102,6 +102,7 @@ REFIT_VOLUME     *SelfVolume = NULL;
 REFIT_VOLUME     **Volumes = NULL;
 UINTN            VolumesCount = 0;
 extern GPT_DATA *gPartitions;
+extern EFI_GUID RefindGuid;
 
 // Maximum size for disk sectors
 #define SECTOR_SIZE 4096
@@ -347,37 +348,58 @@ EFI_STATUS ReinitRefitLib(VOID)
 // EFI variable read and write functions
 //
 
-// From gummiboot: Retrieve a raw EFI variable.
+// Retrieve a raw EFI variable, either from NVRAM or from a disk file under
+// rEFInd's "vars" subdirectory, depending on GlobalConfig.UseNvram.
 // Returns EFI status
 EFI_STATUS EfivarGetRaw(EFI_GUID *vendor, CHAR16 *name, CHAR8 **buffer, UINTN *size) {
-   CHAR8 *buf;
-   UINTN l;
-   EFI_STATUS err;
+    UINT8 *buf = NULL;
+    UINTN l;
+    EFI_STATUS Status;
+    EFI_FILE *VarsDir = NULL;
 
-   l = sizeof(CHAR16 *) * EFI_MAXIMUM_VARIABLE_SIZE;
-   buf = AllocatePool(l);
-   if (!buf)
-      return EFI_OUT_OF_RESOURCES;
-
-   err = refit_call5_wrapper(RT->GetVariable, name, vendor, NULL, &l, buf);
-   if (EFI_ERROR(err) == EFI_SUCCESS) {
-      *buffer = buf;
-      if (size)
-         *size = l;
-   } else
-      MyFreePool(buf);
-   return err;
+    if ((GlobalConfig.UseNvram == FALSE) && GuidsAreEqual(vendor, &RefindGuid)) {
+        Status = refit_call5_wrapper(SelfDir->Open, SelfDir, &VarsDir, L"vars",
+                                  EFI_FILE_MODE_READ | EFI_FILE_MODE_WRITE, EFI_FILE_DIRECTORY);
+        if (Status == EFI_SUCCESS)
+            Status = egLoadFile(VarsDir, name, &buf, size);
+    } else {
+        l = sizeof(CHAR16 *) * EFI_MAXIMUM_VARIABLE_SIZE;
+        buf = AllocatePool(l);
+        if (!buf)
+            return EFI_OUT_OF_RESOURCES;
+        Status = refit_call5_wrapper(RT->GetVariable, name, vendor, NULL, &l, buf);
+    }
+    if (EFI_ERROR(Status) == EFI_SUCCESS) {
+        *buffer = (CHAR8*) buf;
+        if (size)
+            *size = l;
+    } else
+        MyFreePool(buf);
+    return Status;
 } // EFI_STATUS EfivarGetRaw()
 
-// From gummiboot: Set an EFI variable
+// Set an EFI variable, either to NVRAM or to a disk file under rEFInd's
+// "vars" subdirectory, depending on GlobalConfig.UseNvram.
+// Returns EFI status
 EFI_STATUS EfivarSetRaw(EFI_GUID *vendor, CHAR16 *name, CHAR8 *buf, UINTN size, BOOLEAN persistent) {
-   UINT32 flags;
+    UINT32 flags;
+    EFI_FILE *VarsDir = NULL;
+    EFI_STATUS Status;
 
-   flags = EFI_VARIABLE_BOOTSERVICE_ACCESS|EFI_VARIABLE_RUNTIME_ACCESS;
-   if (persistent)
-      flags |= EFI_VARIABLE_NON_VOLATILE;
+    if ((GlobalConfig.UseNvram == FALSE) && GuidsAreEqual(vendor, &RefindGuid)) {
+        Status = refit_call5_wrapper(SelfDir->Open, SelfDir, &VarsDir, L"vars",
+                                 EFI_FILE_MODE_READ | EFI_FILE_MODE_WRITE | EFI_FILE_MODE_CREATE, EFI_FILE_DIRECTORY);
+        if (Status == EFI_SUCCESS) {
+            Status = egSaveFile(VarsDir, name, (UINT8 *) buf, size);
+        }
+    } else {
+        flags = EFI_VARIABLE_BOOTSERVICE_ACCESS|EFI_VARIABLE_RUNTIME_ACCESS;
+        if (persistent)
+            flags |= EFI_VARIABLE_NON_VOLATILE;
 
-   return refit_call5_wrapper(RT->SetVariable, name, vendor, flags, size, buf);
+        Status = refit_call5_wrapper(RT->SetVariable, name, vendor, flags, size, buf);
+    }
+    return Status;
 } // EFI_STATUS EfivarSetRaw()
 
 //
