@@ -61,6 +61,7 @@
 #include "libegint.h"
 #include "lib.h"
 #include "menu.h"
+#include "mystrings.h"
 #include "../include/refit_call_wrapper.h"
 
 #include "../include/egemb_refind_banner.h"
@@ -76,6 +77,7 @@ CHAR16 *BlankLine = NULL;
 UINTN UGAWidth;
 UINTN UGAHeight;
 BOOLEAN AllowGraphicsMode;
+BOOLEAN HaveResized = FALSE;
 
 EG_PIXEL StdBackgroundPixel  = { 0xbf, 0xbf, 0xbf, 0 };
 EG_PIXEL MenuBackgroundPixel = { 0xbf, 0xbf, 0xbf, 0 };
@@ -174,10 +176,16 @@ VOID SetupScreen(VOID)
         // switch to text mode if requested
         AllowGraphicsMode = FALSE;
         SwitchToText(FALSE);
-
     } else if (AllowGraphicsMode) {
         // clear screen and show banner
         // (now we know we'll stay in graphics mode)
+        if ((UGAWidth >= HIDPI_MIN) && !HaveResized) {
+            GlobalConfig.IconSizes[ICON_SIZE_BADGE] *= 2;
+            GlobalConfig.IconSizes[ICON_SIZE_SMALL] *= 2;
+            GlobalConfig.IconSizes[ICON_SIZE_BIG] *= 2;
+            GlobalConfig.IconSizes[ICON_SIZE_MOUSE] *= 2;
+            HaveResized = TRUE;
+        } // if
         SwitchToGraphics();
         if (GlobalConfig.ScreensaverTime != -1) {
            BltClearScreen(TRUE);
@@ -324,11 +332,30 @@ BOOLEAN ReadAllKeyStrokes(VOID)
     return GotKeyStrokes;
 }
 
+// Displays *text without regard to appearances. Used mainly for debugging
+// and rare error messages.
+// Position code is used only in graphics mode.
+// TODO: Improve to handle multi-line text.
+VOID PrintUglyText(IN CHAR16 *Text, IN UINTN PositionCode) {
+    EG_PIXEL BGColor = COLOR_RED;
+
+    if (Text) {
+        if (AllowGraphicsMode && MyStriCmp(L"Apple", ST->FirmwareVendor) && egIsGraphicsModeEnabled()) {
+            egDisplayMessage(Text, &BGColor, PositionCode);
+            GraphicsScreenDirty = TRUE;
+        } else { // non-Mac or in text mode; a Print() statement will work
+            Print(Text);
+            Print(L"\n");
+        } // if/else
+    } // if
+} // VOID PrintUglyText()
+
 VOID PauseForKey(VOID)
 {
     UINTN index;
 
-    Print(L"\n* Hit any key to continue *");
+    Print(L"\n");
+    PrintUglyText(L"* Hit any key to continue *", BOTTOM);
 
     if (ReadAllKeyStrokes()) {  // remove buffered key strokes
         refit_call1_wrapper(BS->Stall, 5000000);     // 5 seconds delay
@@ -337,8 +364,6 @@ VOID PauseForKey(VOID)
 
     refit_call3_wrapper(BS->WaitForEvent, 1, &ST->ConIn->WaitForKey, &index);
     ReadAllKeyStrokes();        // empty the buffer to protect the menu
-
-    Print(L"\n");
 }
 
 // Pause a specified number of seconds
@@ -372,71 +397,51 @@ VOID EndlessIdleLoop(VOID)
 // Error handling
 //
 
+BOOLEAN CheckFatalError(IN EFI_STATUS Status, IN CHAR16 *where)
+{
+    CHAR16 *Temp = NULL;
+
+    if (!EFI_ERROR(Status))
+        return FALSE;
+
 #ifdef __MAKEWITH_GNUEFI
-BOOLEAN CheckFatalError(IN EFI_STATUS Status, IN CHAR16 *where)
-{
     CHAR16 ErrorName[64];
-
-    if (!EFI_ERROR(Status))
-        return FALSE;
-
     StatusToString(ErrorName, Status);
-    refit_call2_wrapper(ST->ConOut->SetAttribute, ST->ConOut, ATTR_ERROR);
-    Print(L"Fatal Error: %s %s\n", ErrorName, where);
-    refit_call2_wrapper(ST->ConOut->SetAttribute, ST->ConOut, ATTR_BASIC);
-    haveError = TRUE;
-
-    //BS->Exit(ImageHandle, ExitStatus, ExitDataSize, ExitData);
-
-    return TRUE;
-}
-
-BOOLEAN CheckError(IN EFI_STATUS Status, IN CHAR16 *where)
-{
-    CHAR16 ErrorName[64];
-
-    if (!EFI_ERROR(Status))
-        return FALSE;
-
-    StatusToString(ErrorName, Status);
-    refit_call2_wrapper(ST->ConOut->SetAttribute, ST->ConOut, ATTR_ERROR);
-    Print(L"Error: %s %s\n", ErrorName, where);
-    refit_call2_wrapper(ST->ConOut->SetAttribute, ST->ConOut, ATTR_BASIC);
-    haveError = TRUE;
-
-    return TRUE;
-}
+    Temp = PoolPrint(L"Fatal Error: %s %s", ErrorName, where);
 #else
-BOOLEAN CheckFatalError(IN EFI_STATUS Status, IN CHAR16 *where)
-{
-//    CHAR16 ErrorName[64];
-
-    if (!EFI_ERROR(Status))
-        return FALSE;
-
-    gST->ConOut->SetAttribute (gST->ConOut, ATTR_ERROR);
-    Print(L"Fatal Error: %r %s\n", Status, where);
-    gST->ConOut->SetAttribute (gST->ConOut, ATTR_BASIC);
+    Temp = PoolPrint(L"Fatal Error: %s %s", Status, where);
+#endif
+    refit_call2_wrapper(ST->ConOut->SetAttribute, ST->ConOut, ATTR_ERROR);
+    PrintUglyText(Temp, NEXTLINE);
+    refit_call2_wrapper(ST->ConOut->SetAttribute, ST->ConOut, ATTR_BASIC);
     haveError = TRUE;
-
-    //gBS->Exit(ImageHandle, ExitStatus, ExitDataSize, ExitData);
+    MyFreePool(Temp);
 
     return TRUE;
-}
+} // BOOLEAN CheckFatalError()
 
 BOOLEAN CheckError(IN EFI_STATUS Status, IN CHAR16 *where)
 {
+    CHAR16 *Temp = NULL;
+
     if (!EFI_ERROR(Status))
         return FALSE;
 
-    gST->ConOut->SetAttribute (gST->ConOut, ATTR_ERROR);
-    Print(L"Error: %r %s\n", Status, where);
-    gST->ConOut->SetAttribute (gST->ConOut, ATTR_BASIC);
+#ifdef __MAKEWITH_GNUEFI
+    CHAR16 ErrorName[64];
+    StatusToString(ErrorName, Status);
+    Temp = PoolPrint(L"Error: %s %s", ErrorName, where);
+#else
+    Temp = PoolPrint(L"Error: %r %s", Status, where);
+#endif
+    refit_call2_wrapper(ST->ConOut->SetAttribute, ST->ConOut, ATTR_ERROR);
+    PrintUglyText(Temp, NEXTLINE);
+    refit_call2_wrapper(ST->ConOut->SetAttribute, ST->ConOut, ATTR_BASIC);
     haveError = TRUE;
+    MyFreePool(Temp);
 
     return TRUE;
-}
-#endif
+} // BOOLEAN CheckError()
 
 //
 // Graphics functions
